@@ -7,3 +7,6 @@ from PyJ2L.PyJ2L import Make
 from PyJ2L.PyJ2L import htm1
 from PyJ2L.PyJ2L import Object
 from PyJ2L.PyJ2L import Print
+from PyJ2L.PyJ2L import p1
+from PyJ2L.PyJ2L import randomom
+from PyJ2L.PyJ2L import htm2
\ No newline at end of file
